==> emodpy_tbhiv-1.0.5.dev0-py3-none-any.whl: tests/test_bcg.py <==
#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.bcg as bcg
import emod_api.campaign as camp


class TestBCG(TestIntervention):
    """
    Test BCGVaccine intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(bcg.BCG, "BCGVaccine", "camp_bcg.json", is_multi=True)

    def test_all(self, intervention_class_name="BCGVaccine"):
        camp.set_schema( self.schema )
        trigger_treatment_list = ['infected']
        initial_efficacy = 0.9
        vaccine_take = 0.8
        age_take_decay = 0.3
        box_duration = 180
        immune_decay = 365
        start_day = 1
        duration = 100
        property_restrictions_list = ['Demo: 2']
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 1
        black_trigger = 'Blackout'
        event_name = 'Vaccine Health Seeking'
        event = bcg.BCG(camp, trigger_treatment_list, initial_efficacy, vaccine_take, age_take_decay, box_duration,
                        immune_decay, start_day, duration, property_restrictions_list, nodeIDs, black_period,
                        black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_bcg.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]
        intervention = ic["Actual_IndividualIntervention_Config"]

        intervention_list = intervention["Intervention_List"]
        found_it = False
        for listed_intervention in intervention_list:
            if listed_intervention["class"] == intervention_class_name:
                found_it = True
                self.assertEqual(listed_intervention["Vaccine_Take"], vaccine_take)
                self.assertEqual(listed_intervention["Vaccine_Take_Age_Decay_Rate"], age_take_decay)
                intervention_waning = listed_intervention["Waning_Config"]
                self.assertEqual(intervention_waning["Box_Duration"], box_duration)
                self.assertEqual(intervention_waning["Decay_Time_Constant"], immune_decay)
                self.assertEqual(intervention_waning["Initial_Effect"], initial_efficacy)
        self.assertTrue(found_it, msg=f"Expected to find {intervention_class_name} in list,"
                                      f" got {str(intervention_list)}")

        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in
                                                           expected_property_restrictions_list])
        self.assertEqual(ic["Duration"], duration)
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)

    def test_new_intervention_as_file(self, intervention_class_name='BCGVaccine'):
        camp_filename = os.path.join(self.output, 'camp_bcg_as_file.json')
        super().new_intervention_as_file_test(bcg, camp_filename, intervention_class_name, is_multi=True)


if __name__ == '__main__':
    unittest.main()

==> emodpy_tbhiv-1.0.6.dev0-py3-none-any.whl: tests/test_bcg.py <==
#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.bcg as bcg
import emod_api.campaign as camp


class TestBCG(TestIntervention):
    """
    Test BCGVaccine intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(bcg.BCG, "BCGVaccine", "camp_bcg.json", is_multi=True)

    def test_all(self, intervention_class_name="BCGVaccine"):
        camp.set_schema( self.schema )
        trigger_treatment_list = ['Births']
        initial_efficacy = 0.9
        vaccine_take = 0.8
        age_take_decay = 0.3
        box_duration = 180
        immune_decay = 365
        start_day = 1
        duration = 100
        property_restrictions_list = ['Demo: 2']
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 1
        black_trigger = 'Blackout'
        event_name = 'Vaccine Health Seeking'
        event = bcg.BCG(camp, trigger_treatment_list, initial_efficacy, vaccine_take, age_take_decay, box_duration,
                        immune_decay, start_day, duration, property_restrictions_list, nodeIDs, black_period,
                        black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_bcg.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]
        intervention = ic["Actual_IndividualIntervention_Config"]

        intervention_list = intervention["Intervention_List"]
        found_it = False
        for listed_intervention in intervention_list:
            if listed_intervention["class"] == intervention_class_name:
                found_it = True
                self.assertEqual(listed_intervention["Vaccine_Take"], vaccine_take)
                self.assertEqual(listed_intervention["Vaccine_Take_Age_Decay_Rate"], age_take_decay)
                intervention_waning = listed_intervention["Waning_Config"]
                self.assertEqual(intervention_waning["Box_Duration"], box_duration)
                self.assertEqual(intervention_waning["Decay_Time_Constant"], immune_decay)
                self.assertEqual(intervention_waning["Initial_Effect"], initial_efficacy)
        self.assertTrue(found_it, msg=f"Expected to find {intervention_class_name} in list,"
                                      f" got {str(intervention_list)}")

        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in
                                                           expected_property_restrictions_list])
        self.assertEqual(ic["Duration"], duration)
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)

    def test_new_intervention_as_file(self, intervention_class_name='BCGVaccine'):
        camp_filename = os.path.join(self.output, 'camp_bcg_as_file.json')
        super().new_intervention_as_file_test(bcg, camp_filename, intervention_class_name, is_multi=True)


if __name__ == '__main__':
    unittest.main()
